@@ -1,6 +1,6 @@
 package Zabbix::Reporter;
 {
-  $Zabbix::Reporter::VERSION = '0.04';
+  $Zabbix::Reporter::VERSION = '0.05';
 }
 BEGIN {
   $Zabbix::Reporter::AUTHORITY = 'cpan:TEX';
@@ -66,7 +66,7 @@ with qw(Config::Yak::RequiredConfig Log::Tree::RequiredLogger);
 
 sub _dsn {
     my $self = shift;
-    
+
     my $hostname = $self->config()->get( 'Zabbix::Reporter::DB::Hostname', { Default => 'localhost', } );
     my $port = $self->config()->get( 'Zabbix::Reporter::DB::Port', { Default => 3306, } );
     my $database = $self->config()->get( 'Zabbix::Reporter::DB::Database', { Default => 'zabbix', } );
@@ -86,18 +86,18 @@ sub _init_dbh {
 
     my $dbh = DBI->connect($self->_dsn());
     $dbh->{'mysql_auto_reconnect'} = 1;
-    
+
     return $dbh;
 }
 
 sub _init_cache {
     my $self = shift;
-    
+
     my $Cache = Cache::MemoryCache::->new({
       'namespace'          => 'ZabbixReporter',
       'default_expires_in' => 600,
     });
-    
+
     return $Cache;
 }
 
@@ -106,16 +106,16 @@ sub fetch_n_store {
     my $query = shift;
     my $timeout = shift;
     my @args = @_;
-    
+
     my $key = $query.join(',',@args);
-    
+
     my $result = $self->cache()->get($key);
-    
+
     if( ! defined($result) ) {
         $result = $self->fetch($query,@args);
         $self->cache()->set($key,$result,$timeout);
     }
-    
+
     return $result;
 }
 
@@ -123,26 +123,26 @@ sub fetch {
     my $self = shift;
     my $query = shift;
     my @args = @_;
-    
+
     my $sth = $self->dbh()->prepare($query)
         or die("Could not prepare query $query: ".$self->dbh()->errstr);
-    
+
     $sth->execute(@args)
         or die("Could not execute query $query: ".$self->dbh()->errstr);
-    
+
     my @result = ();
-    
+
     while(my $ref = $sth->fetchrow_hashref()) {
         push(@result,$ref);
     }
     $sth->finish();
-    
+
     return \@result;
 }
 
 sub triggers {
     my $self = shift;
-    
+
     my $sql = <<'EOS';
 SELECT
     t.priority,
@@ -175,7 +175,7 @@ EOS
         $sql .= ' AND t.priority IN ('.join(',',@{$self->priorities()}).')';
     }
     if($self->min_age()) {
-        $sql .= ' AND t.lastchange < NOW() - INTERVAL '.$self->min_age().' MINUTE';
+        $sql .= ' AND t.lastchange < UNIX_TIMESTAMP(NOW() - INTERVAL '.$self->min_age().' MINUTE)';
     }
     if($self->groups() && @{$self->groups()} > 0) {
         my $sub_sql = "SELECT hostid FROM host_groups WHERE groupid IN (".join(',',@{$self->groups()}).")";
@@ -229,7 +229,7 @@ EOS
       };
       unshift @{$rows}, $row;
    }
-    
+
     return $rows;
 }
 
@@ -237,7 +237,7 @@ sub acks {
     my $self = shift;
     my $triggerid = shift;
     my $triggerclock = shift;
-    
+
     my $sql = <<'EOS';
 SELECT
    e.eventid,
@@ -279,13 +279,13 @@ EOS
             }
         }
     }
-    
+
     return $rows;
 }
 
 sub disabled_actions {
     my $self = shift;
-    
+
     # status = 0 -> action is enabled
     # status = 1 -> action is disabled
     my $sql = <<'EOS';
