@@ -1,6 +1,6 @@
 package Zabbix::Reporter::Web::Plugin::List;
 {
-  $Zabbix::Reporter::Web::Plugin::List::VERSION = '0.04';
+  $Zabbix::Reporter::Web::Plugin::List::VERSION = '0.05';
 }
 BEGIN {
   $Zabbix::Reporter::Web::Plugin::List::AUTHORITY = 'cpan:TEX';
@@ -35,7 +35,7 @@ sub _init_alias { return 'list_triggers'; }
 sub execute {
     my $self = shift;
     my $request = shift;
-    
+
     my $triggers = $self->zr()->triggers();
     my $refresh  = $request->{'refresh'} || 30;
 
@@ -48,8 +48,11 @@ sub execute {
         },
         \$body,
     ) or $self->logger()->log( message => 'TT error: '.$self->tt()->error, level => 'warning', );
-    
-    return [ 200, [ 'Content-Type', 'text/html' ], [$body] ];
+
+    return [ 200, [
+      'Content-Type', 'text/html',
+      'Cache-Control', 'max-age='.($refresh-1).', private',
+    ], [$body] ];
 }
 
 no Moose;
